vortex\_properties package
======================================

.. automodule:: IMTreatment.vortex_properties
    :members:
    :undoc-members:
    :show-inheritance:

.. toctree::

   IMTreatment.vortex_properties.vortex_properties

